#!/usr/bin/python
# -*- coding: utf-8 -*-

# django-bipipe
# https://github.com/orygens/django-bigpipe

# Licensed under the MIT license:
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 Orygens contato@orygens.com

from django.template.loader import render_to_string
from django.template import RequestContext
from django.http import HttpResponse

def render_pagelets(request, template_name='base.html',
    pagelets=[], extra_context=[]):
    return HttpResponse(stream_pagelets(request,
      template_name, pagelets, extra_context))

def stream_pagelets(request, template_name, pagelets, extra_context):
    """
    Render the basic page structure and flush each pagelet response.
    """
    yield render_to_string(template_name, extra_context,
        context_instance=RequestContext(request))

    for pagelet in pagelets:
        yield pagelet.render()

    yield '</body></html>\n'




#!/usr/bin/python
# -*- coding: utf-8 -*-

# django-bipipe
# https://github.com/orygens/django-bigpipe

# Licensed under the MIT license:
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 Orygens contato@orygens.com

from django.conf import settings
from django.template import RequestContext
from django.template.loader import render_to_string

class Pagelet(object):
    """
    Simple parent class for all pagelets. Only implements rendering.
    """

    js = []
    css = []
    context = {}
    is_last = False
    content_template = None

    def __init__(self, id, request, **kwargs):
        self.id = id
        self.request = request
        
        cls = self.__class__
        for key, value in kwargs.iteritems():
          if not hasattr(cls, key):
              raise TypeError(u'%s() received an invalid keyword %r' %
                  (cls.__name__, key))

          setattr(self, key, value)

    def get_context_data(self):
        """
        Simple context generating. Subclasses must override this method
        to add more data to the context passed to template.
        """

        return self.context

    def get_js_resources(self):
        return self._get_static_resources('js')

    def get_css_resources(self):
        return self._get_static_resources('css')

    def _get_static_resources(self, name):
        return map(lambda s: '%s%s' % (settings.MEDIA_URL, s),
            getattr(self, name))

    def get_html_content(self):
        content = ''

        if self.content_template:
            content = render_to_string(self.content_template,
                self.get_context_data(), RequestContext(self.request))

        return content

    def render(self):
        return render_to_string('bigpipe/pagelet.html',
            {'pagelet': self}, RequestContext(self.request))




#!/usr/bin/python
# -*- coding: utf-8 -*-

# django-bipipe
# https://github.com/orygens/django-bigpipe

# Licensed under the MIT license:
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 Orygens contato@orygens.com

from setuptools import setup, find_packages
from django_bigpipe import __version__

setup(
    name = 'django-bigpipe',
    version = '.'.join([str(item) for item in __version__]),
    description = "django-bigpipe are a jquery-bigpipe extension to django web framework.",
    long_description = """
django-bigpipe are a jquery-bigpipe (https://github.com/orygens/jquery-bigpipe) extension to django web framework.
""",
    keywords = 'django web',
    author = u'Orygens',
    author_email = 'contato@orygens.com',
    url = 'https://github.com/orygens/django-bigpipe',
    license = 'MIT',
    classifiers = ['Development Status :: 3 - Alpha',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: MIT License',
                   'Natural Language :: English',
                   'Operating System :: MacOS',
                   'Operating System :: POSIX :: Linux',
                   'Programming Language :: Python :: 2.6'
    ],
    packages = find_packages(),
    package_dir = {"django_bigpipe": "django_bigpipe"},

    install_requires=[
        "django"
    ],

)
